<?php
/* Copyright (C) 2015       Charles-fr BENKE            <charles.fr@benke.fr>
 * Copyright (C) 2016		Philippe SAGOT (Philazerty)	<courrier@mon-dolibarr.fr>
 * Copyright (C) 2017	    Laurent DINCLAUX (loxK)   <laurent@gecka.nc>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 *        \file       htdocs/geckanewcaledonia/admin/setup.php
 *        \ingroup    geckanewcaledonia
 *        \brief      Page to setup the module geckanewcaledonia
 */

// Dolibarr environment
//uggly hack to work arround module being symlink to a dolibarr install
$_dir = dirname(dirname(dirname($_SERVER['SCRIPT_FILENAME'])));

$res = 0;
if (! $res && file_exists($_dir . "/main.inc.php")) {
    $res = @include($_dir . "/main.inc.php");
}        // For root directory
if (! $res && file_exists($_dir . "/../main.inc.php")) {
    $res = @include($_dir . "/../main.inc.php");
}    // For "custom" directory

require_once DOL_DOCUMENT_ROOT . '/core/lib/admin.lib.php';
dol_include_once('/geckanewcaledonia/core/lib/main.lib.php');

$langs->load("admin");
$langs->load("geckanewcaledonia@geckanewcaledonia");

if (! $user->admin) {
    accessforbidden();
}

$action = GETPOST('action', 'alpha');

// Parameters GKNC_* and others
$list = array(
    'GKNC_MAIN_TEXT_COLOR',
    'GKNC_BRANDING_TEXT_COLOR',
    'GKNC_TABLE_LINES_COLORS',
    'GKNC_BOXES_BACKGROUND',
    'GKNC_TEMPLATE_TAXE_COLUMN',
);

/*
 * Actions
 */
if ($action == 'update') {
    $error = 0;

    foreach ($list as $constname) {
        $constvalue = GETPOST($constname, 'alpha');

        if (! dolibarr_set_const($db, $constname, $constvalue, 'chaine', 0, '', $conf->entity)) {
            $error ++;
        }
    }

    if (! $error) {
        setEventMessages($langs->trans("SetupSaved"), null, 'mesgs');
    } else {
        setEventMessages($langs->trans("Error"), null, 'errors');
    }
}
if ($action == 'setfranchise') {
    $setfranchise = GETPOST('value', 'int');
    $res          = dolibarr_set_const($db, "GKNC_FORCE_FRANCHISE", $setfranchise, 'yesno', 0, '', $conf->entity);
    if (! $res > 0) {
        $error ++;
    }

    if (! $error) {
        setEventMessages($langs->trans("SetupSaved"), null, 'mesgs');
    } else {
        setEventMessages($langs->trans("Error"), null, 'mesgs');
    }
}

if ($action == 'setvatcalccol') {
    $setvatcalccol = GETPOST('value', 'int');
    $res           = dolibarr_set_const($db, "GKNC_SHOW_VATCALC_COL", $setvatcalccol, 'yesno', 0, '', $conf->entity);
    if (! $res > 0) {
        $error ++;
    }

    if (! $error) {
        setEventMessages($langs->trans("SetupSaved"), null, 'mesgs');
    } else {
        setEventMessages($langs->trans("Error"), null, 'mesgs');
    }
}

if ($action == 'setfoldmark') {
    $setfoldmark = GETPOST('value', 'int');
    $res         = dolibarr_set_const($db, "GKNC_FOLD_MARK", $setfoldmark, 'yesno', 0, '', $conf->entity);
    if (! $res > 0) {
        $error ++;
    }

    if (! $error) {
        setEventMessages($langs->trans("SetupSaved"), null, 'mesgs');
    } else {
        setEventMessages($langs->trans("Error"), null, 'mesgs');
    }
}


/*
 * View
 */
llxHeader('', $langs->trans("GeckaNewCaledonia"), $help_url);

$form = new Form($db);

$linkback = '<a href="' . DOL_URL_ROOT . '/admin/modules.php">' . $langs->trans("BackToModuleList") . '</a>';
print load_fiche_titre($langs->trans("GeckaNewCaledoniaSetup"), $linkback, 'title_setup');

$head = geckanewcaledonia_admin_prepare_head();
dol_fiche_head($head, 'setup', $langs->trans("GeckaNewCaledonia"), 0, 'list');

print '<form action="' . $_SERVER["PHP_SELF"] . '" method="post">';
print '<input type="hidden" name="token" value="' . $_SESSION['newtoken'] . '">';
print '<input type="hidden" name="action" value="update">';

print '<table class="noborder" width="100%">';
print '<tr class="liste_titre">';
print '<td colspan="2">' . $langs->trans('Options des modèles') . '</td>';
print "</tr>\n";

foreach ($list as $key) {
    $var = ! $var;

    print '<tr ' . $bc[ $var ] . ' class="value">';
    // Param
    $label = $langs->trans($key . '_LABEL');
    print '<td>' . $label . '</td>';
    // Value
    print '<td align="right">';
    if ($key === 'GKNC_TEMPLATE_TAXE_COLUMN') {
        print '<label><input type="radio" id="' . $key . '" name="' . $key . '" value="0"' . ( $conf->global->$key === '0' ? 'checked="checked"' : '' ) . '> Comportement par défaut</label><br>';
        print '<label><input type="radio" id="' . $key . '" name="' . $key . '" value="1"' . ( $conf->global->$key === '1' ? 'checked="checked"' : '' ) . '> Afficher que la TGC</label><br>';
        print '<label><input type="radio" id="' . $key . '" name="' . $key . '" value="2"' . ( $conf->global->$key === '2' ? 'checked="checked"' : '' ) . '> Additionner TGC et autres taxes</label><br>';
        print '<label><input type="radio" id="' . $key . '" name="' . $key . '" value="3"' . ( $conf->global->$key === '3' ? 'checked="checked"' : '' ) . '> Une colonne par taxe</label><br>';
    } else {
        print '<input type="text" size="20" id="' . $key . '" name="' . $key . '" value="' . $conf->global->$key . '">';
    }
    print '</td>';
    print '</tr>';
}

if (! empty($user->admin)) {
    $var = ! $var;
    print "<tr " . $bc[ $var ] . ">";
    print '<td>' . $langs->trans("GKNC_FORCE_FRANCHISE_LABEL") . '</td>';
    if (! empty($conf->global->GKNC_FORCE_FRANCHISE)) {
        print '<td align="right"><a href="' . $_SERVER['PHP_SELF'] . '?action=setfranchise&value=0">';
        print img_picto($langs->trans("Activated"), 'switch_on');
        print '</a></td>';
    } else {
        print '<td align="right"><a href="' . $_SERVER['PHP_SELF'] . '?action=setfranchise&value=1">';
        print img_picto($langs->trans("Disabled"), 'switch_off');
        print '</a></td>';
    }
    print '</tr>';

    $var = ! $var;
    print "<tr " . $bc[ $var ] . ">";
    print '<td>' . $langs->trans("GKNC_SHOW_VATCALC_COL_LABEL") . '</td>';
    if (! empty($conf->global->GKNC_SHOW_VATCALC_COL)) {
        print '<td align="right"><a href="' . $_SERVER['PHP_SELF'] . '?action=setvatcalccol&value=0">';
        print img_picto($langs->trans("Activated"), 'switch_on');
        print '</a></td>';
    } else {
        print '<td align="right"><a href="' . $_SERVER['PHP_SELF'] . '?action=setvatcalccol&value=1">';
        print img_picto($langs->trans("Disabled"), 'switch_off');
        print '</a></td>';
    }
    print '</tr>';

    $var = ! $var;
    print "<tr " . $bc[ $var ] . ">";
    print '<td>' . $langs->trans("GKNC_FOLD_MARK_LABEL") . '</td>';
    if (! empty($conf->global->GKNC_FOLD_MARK)) {
        print '<td align="right"><a href="' . $_SERVER['PHP_SELF'] . '?action=setfoldmark&value=0">';
        print img_picto($langs->trans("Activated"), 'switch_on');
        print '</a></td>';
    } else {
        print '<td align="right"><a href="' . $_SERVER['PHP_SELF'] . '?action=setfoldmark&value=1">';
        print img_picto($langs->trans("Disabled"), 'switch_off');
        print '</a></td>';
    }
    print '</tr>';
}

print '</table>';

dol_fiche_end();

print '<div class="center"><input type="submit" class="button" value="' . $langs->trans('Modify') . '" name="button"></div>';

print '<br>';
print '<br>';

llxFooter();
$db->close();
